# bibtex-pruner
When a bibTeX file exported by Zotero contains too many unnecessary fields
当Zotero导出的bibTeX文件包含了太多不需要的字段

简体中文 | English

## 适用场景

国标模板

## 同类工具

* bibtex-clean: [GitHub(CangyuanLi/bibtex_fields)](https://github.com/CangyuanLi/bibtex_fields), [PyPi(bibtex-clean)](https://pypi.org/project/bibtex-clean/)
